/*
AI-------------------------------------------------------------------
	List of chatrooms container.
-------------------------------------------------------------------AI
*/

.search {
	height: 60px;
}

.search-form {
	margin-bottom: 0px;
	width: 100%;
	height: 100%;
	display: flex;
	flex-direction: row;
	align-items: center;
	justify-content: space-around;
}

.select-chat-user {
	width: 80% !important;
}

.select-chat-button {
	width: 20%;
	border: none;
	background: white;
}

.chatroom-list {
	display: flex;
	flex-direction: column;
}

.chatroom-list-title {
	height: 60px;
	display: flex;
	align-items: center;
	font-size: 20px;
	padding-left: 20px;
}

.list-room {
	height: 70px;
	width: 100%;
	display: flex;
	align-items: center;
	text-decoration: none;
	color: black;
	cursor:pointer;
}

.chat-list-item {
	margin-left: 20px;
	width: calc(100% - 20px);
}

.chat-list-title {
	font-size: 18px;
}

.chat-list-last-message {
	width: 90%;
	margin-top: 5px;
	font-size: 14px;
	color: #606060;
	text-overflow: ellipsis;
	overflow: hidden;
	white-space: nowrap;
}

.list-room:hover {
	background-color: var(--bg-grey);
}
